from django.db import models
from django.core.management import call_command
from generic_helpers.models import GenericRelationModel

FOO_NUMBER = 3
BAR_NUMBER = 3

class Foo(models.Model):
    title = models.CharField('Title', max_length=255)

    class Meta:
        app_label = 'generic_helpers'

class Bar(GenericRelationModel):
    title = models.CharField('Title', max_length=255)

    class Meta:
        app_label = 'generic_helpers'

def load_test_data():
    for i in xrange(1, FOO_NUMBER + 1):
        foo = Foo.objects.create(title='Foo #%s' % i)

        for j in xrange(1, BAR_NUMBER + 1):
            bar = Bar.objects.create(title='Bar #%s' % i, content_object=foo)
        
call_command('syncdb', interactive=False, verbosity=0)



from django.db import models
from django.contrib.contenttypes.models import ContentType

class GenericQuerySet(models.query.QuerySet):
    def get_for_object(self, object):
        return self.select_related().filter(
            content_type = ContentType.objects.get_for_model(object),
            object_pk    = object.pk,
        )

    def get_for_model(self, model):
        return self.select_related().filter(
            content_type=ContentType.objects.get_for_model(model)
        )

class GenericRelationManager(models.Manager):
    def get_query_set(self):
        return GenericQuerySet(self.model)

    def get_for_object(self, object):
        return self.get_query_set().select_related().\
            filter(
                content_type = ContentType.objects.get_for_model(object),
                object_pk    = object.pk,
            )
    def get_for_model(self, model):
        return self.get_query_set().select_related().\
            filter(content_type=ContentType.objects.get_for_model(model)
        )


from django.db import models
from django.contrib.contenttypes import generic
from django.utils.translation import ugettext_lazy as _
from generic_helpers.managers import GenericRelationManager, ContentType

class GenericRelationModel(models.Model):
    content_type = models.ForeignKey(ContentType,
        verbose_name = _('Content type'),
        related_name = 'content_type_set_for_%(class)s'
    )
    object_pk = models.TextField(
        verbose_name = _('Object ID'),
    )
    content_object = generic.GenericForeignKey(
        ct_field   = 'content_type',
        fk_field   = 'object_pk',        
    )
    objects = GenericRelationManager()

    class Meta:
        abstract = True



#!/usr/bin/env python
from distutils.core import setup
import os

version='0.1.1'
package = 'generic_helpers'

setup(
    name = 'django-generic-helpers',
    version = version,
    author  = 'marazmiki',
    author_email = 'marazmiki@gmail.com',
    url = 'http://bitbucket.org/marazmiki/django-generic-helpers/',
    download_url = 'http://bitbucket.org/marazmiki/django-generic-helpers/get/tip.zip',

    description = 'This app makes it easy to display a map for a given address.',
    long_description = open('README.rst').read(),
    license = 'MIT license',
    requires = ['django (>=1.2)'],

    packages=['generic_helpers', 'generic_helpers.tests'],

    classifiers=[
        'Development Status :: 4 - Beta',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
)
